summaryrefslogtreecommitdiffstats
path: root/chrome/browser/cocoa/fullscreen_controller.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/cocoa/fullscreen_controller.h')
-rw-r--r--chrome/browser/cocoa/fullscreen_controller.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/chrome/browser/cocoa/fullscreen_controller.h b/chrome/browser/cocoa/fullscreen_controller.h
index f599835..832d3de 100644
--- a/chrome/browser/cocoa/fullscreen_controller.h
+++ b/chrome/browser/cocoa/fullscreen_controller.h
@@ -83,10 +83,11 @@
showDropdown:(BOOL)showDropdown;
- (void)exitFullscreen;
-// Returns the amount by which the tab strip should be offset and the overlay
-// view should be enlarged, vertically. Generally, this is > 0 when the
-// fullscreen window is on the primary screen and 0 otherwise.
-- (CGFloat)tabStripVerticalOffset;
+// Returns the amount by which the floating bar should be offset downwards (to
+// avoid the menu) and by which the overlay view should be enlarged vertically.
+// Generally, this is > 0 when the fullscreen window is on the primary screen
+// and 0 otherwise.
+- (CGFloat)floatingBarVerticalOffset;
// Informs the controller that the overlay's frame has changed. The controller
// uses this information to update its tracking areas.